==> material-0.0.6.tgz: package/lib/form/fieldset.js <==
'use strict';

var Element = require('../element');

/**
 * Module fieldset
 * @module form/fieldset
 */
var fieldset = {

	/**
	 * Initialize form fieldset
	 * @return {void}
	 */
	_initFieldset(fieldset, form) {
		var legend = null;

		var element = new Element('div', {
			'class': 'form-fieldset',
		}).inject(form);

		if (fieldset.name)
			element.addClass('fieldset-'+ fieldset.name);

		if (fieldset.klss)
			element.addClass(fieldset.klss);

		if (fieldset.state === 'closed')
			element.addClass('closed');

		if (fieldset.text) {
			legend = new Element('span', {
				'class': 'fieldset-legend',
				
			}).inject(element);

			legend.text(fieldset.text);
			legend.attribute('data-name', fieldset.text);

			var caret = new Element('span', {
				'class': 'icon-font mdi_navigation_chevron_right'
			}).inject(legend, 'top');
		}

		if (fieldset.buttons) {
			this._initButtons(fieldset.buttons, this.doc, legend);
		}

		if (legend)
			element.store('legend', legend);

		// if (typeOf(fieldset.menu) == 'object') {
		// 	this._initFieldsetMenu(fieldset.menu, legend);
		// } else if (typeOf(fieldset.menu) == 'array') {
		// 	for (var i = 0; i < fieldset.menu.length; i++) {
		// 		var menu = fieldset.menu[i];
		// 		this._initFieldsetMenu(menu, legend);
		// 	}
		// }

		if (fieldset.field) {
			this._initObjectField(fieldset.field, element);
		} else if (fieldset.fields) {
			this._initFields(fieldset.fields, element);
		}
	}

	// /**
	//  * Initialize form fieldset menu if exists
	//  * @return {void}
	//  */
	// _initFieldsetMenu(menu, legend) {
	// 	var self = this;

	// 	var addBtn = new ButtonControl(menu)
	// 	.inject(legend);

	// 	addBtn.on(menu.emit, function(){
	// 		self.fireEvent(menu.emit, self);
	// 	});


	// }

};

module.exports = fieldset;

==> material-0.1.0.tgz: package/lib/form/fieldset.js <==
'use strict';

var Component = require('../component');

/**
 * Module fieldset
 * @module form/fieldset
 */
var fieldset = {

	/**
	 * Initialize form fieldset
	 * @return {void}
	 */
	_initFieldset(fieldset, form) {
		var legend = null;

		var component = new Component({
			'class': 'form-fieldset',
		}).inject(form);

		if (fieldset.name)
			component.addClass('fieldset-'+ fieldset.name);

		if (fieldset.klss)
			component.addClass(fieldset.klss);

		if (fieldset.state === 'closed')
			component.addClass('closed');

		if (fieldset.text) {
			legend = new Component({
				'class': 'fieldset-legend',
				
			}).inject(component);

			legend.text(fieldset.text);
			legend.attribute('data-name', fieldset.text);

			var caret = new Component({
				'class': 'icon-font mdi_navigation_chevron_right'
			}).inject(legend, 'top');
		}

		if (fieldset.buttons) {
			this._initButtons(fieldset.buttons, this.doc, legend);
		}

		// if (legend)
		// 	element.store('legend', legend);

		// if (typeOf(fieldset.menu) == 'object') {
		// 	this._initFieldsetMenu(fieldset.menu, legend);
		// } else if (typeOf(fieldset.menu) == 'array') {
		// 	for (var i = 0; i < fieldset.menu.length; i++) {
		// 		var menu = fieldset.menu[i];
		// 		this._initFieldsetMenu(menu, legend);
		// 	}
		// }

		if (fieldset.field) {
			this._initObjectField(fieldset.field, component);
		} else if (fieldset.fields) {
			this._initFields(fieldset.fields, component);
		}
	}

	// /**
	//  * Initialize form fieldset menu if exists
	//  * @return {void}
	//  */
	// _initFieldsetMenu(menu, legend) {
	// 	var self = this;

	// 	var addBtn = new ButtonControl(menu)
	// 	.inject(legend);

	// 	addBtn.on(menu.emit, function(){
	// 		self.fireEvent(menu.emit, self);
	// 	});


	// }

};

module.exports = fieldset;
